==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/Mono.Messaging.RabbitMQ/Test/Mono.Messaging.RabbitMQ/MessageTest.cs <==
//
// MessageTest.cs -
//    NUnit Test Cases for MessageQueuePermissionAttribute
//
// Author:
//    Michael Barker  <sebastien@ximian.com>
//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using NUnit.Framework;
using NUnit.Mocks;
using System;
//using System.Messaging;
using System.Security;
using System.Security.Permissions;
using System.Reflection;

using Mono.Messaging;

namespace MonoTests.Mono.Messaging.RabbitMQ {

    [TestFixture]
    public class MessageTest {
    
        DynamicMock messageMock;
        IMessage iMessage;
        
        [SetUp]
        public void SetUp ()
        {
            messageMock = new DynamicMock (typeof (IMessage));
            iMessage = (IMessage) messageMock.MockInstance;
        }

        [Test]
        public void SetProperties ()
        {
            messageMock.Expect ("set_AcknowledgeType", 
                AcknowledgeTypes.FullReachQueue);
                
            System.Messaging.Message m = TestUtils.CreateMessage (iMessage);
            m.AcknowledgeType = System.Messaging.AcknowledgeTypes.FullReachQueue;
            
            messageMock.Verify ();
        }
    }
}

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/Mono.Messaging.RabbitMQ/Test/Mono.Messaging.RabbitMQ/MessageTest.cs <==
//
// MessageTest.cs -
//    NUnit Test Cases for MessageQueuePermissionAttribute
//
// Author:
//    Michael Barker  <sebastien@ximian.com>
//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using NUnit.Framework;
using NUnit.Mocks;
using System;
using System.Security;
using System.Security.Permissions;
using System.Reflection;
using SystemMessage = System.Messaging.Message;
using SystemAcknowledgeTypes = System.Messaging.AcknowledgeTypes;

using Mono.Messaging;

namespace MonoTests.Mono.Messaging.RabbitMQ {

    [TestFixture]
    public class MessageTest {
    
        DynamicMock messageMock;
        IMessage iMessage;
        
        [SetUp]
        public void SetUp ()
        {
            messageMock = new DynamicMock (typeof (IMessage));
            iMessage = (IMessage) messageMock.MockInstance;
        }

        [Test]
        public void SetProperties ()
        {
            messageMock.Expect ("set_AcknowledgeType", 
                AcknowledgeTypes.FullReachQueue);
                
            SystemMessage m = TestUtils.CreateMessage (iMessage);
            m.AcknowledgeType = SystemAcknowledgeTypes.FullReachQueue;
            
            messageMock.Verify ();
        }
    }
}
